VERSION = (1, 0, 12)
__version__ = ".".join(map(str, VERSION))

default_app_config = "binary_database_files.apps.DatabaseFilesAppConfig"
